@@ -12,7 +12,7 @@
 #include "mwdg/mixer_device_setup.hpp"
 #include "mwdg/inputs_setup.hpp"
 #include "views/mixer_hctl_setup.hpp"
-#include "views/dev_select_view_setup.hpp"
+#include "views/device_selection_view_setup.hpp"
 
 #include <QByteArray>
 #include <QKeySequence>
@@ -37,7 +37,7 @@ class Main_Window_Setup
 	::MWdg::Inputs_Setup inputs;
 
 	::Views::Mixer_HCTL_Setup hctl;
-	::Views::Dev_Select_View_Setup dev_select;
+	::Views::Device_Selection_View_Setup dev_select;
 };
 
 
