@@ -14,8 +14,8 @@
 
 // Forward declaration
 namespace QSnd {
-	class CTL_Def;
-	class Controls_DB;
+	class CTL_Format;
+	class Controls_Database;
 }
 
 
@@ -42,22 +42,27 @@ class Controls_Model :
 
 	// Controls database
 
-	::QSnd::Controls_DB *
+	::QSnd::Controls_Database *
 	controls_db ( ) const;
 
 	void
 	set_controls_db (
-		::QSnd::Controls_DB * ctl_db_n );
+		::QSnd::Controls_Database * ctl_db_n );
 
 
 	// Control definition access
 
-	const ::QSnd::CTL_Def *
-	ctl_def (
+	const ::QSnd::CTL_Format *
+	ctl_format (
+		const QModelIndex & idx_n ) const;
+
+	void
+	ctl_format (
+		::QSnd::CTL_Format & ctl_format_n,
 		const QModelIndex & idx_n ) const;
 
 	QModelIndex
-	ctl_def_index (
+	ctl_format_index (
 		const QString & ctl_addr_n ) const;
 
 
@@ -88,12 +93,12 @@ class Controls_Model :
 	// Private attributes
 	private:
 
-	::QSnd::Controls_DB * _ctl_db;
+	::QSnd::Controls_Database * _ctl_db;
 };
 
 
 inline
-::QSnd::Controls_DB *
+::QSnd::Controls_Database *
 Controls_Model::controls_db ( ) const
 {
 	return _ctl_db;
